@@ -7,6 +7,8 @@ use itertools::iproduct;
 use itertools::Itertools;
 use num_traits::Signed;
 use std::collections::BTreeSet;
+use std::iter::FusedIterator;
+use std::mem::MaybeUninit;
 use std::ops::{Deref, DerefMut, Index, IndexMut, Neg, Range};
 use std::slice::{Iter, IterMut};
 use thiserror::Error;
@@ -217,6 +219,20 @@ impl<C> Matrix<C> {
         })
     }
 
+    /// Construct a new Matrix with uninitialized content.
+    pub fn new_uninit(rows: usize, columns: usize) -> Matrix<MaybeUninit<C>> {
+        let data_len = rows * columns;
+        let mut data = Vec::with_capacity(data_len);
+        unsafe {
+            data.set_len(data_len);
+        }
+        Matrix {
+            rows,
+            columns,
+            data,
+        }
+    }
+
     /// Create new square matrix from vector values. The first value
     /// will be assigned to index (0, 0), the second one to index (0, 1),
     /// and so on. An error is returned if the number of values is not a
@@ -607,6 +623,23 @@ impl<C> Matrix<C> {
     }
 }
 
+impl<C> Matrix<MaybeUninit<C>> {
+    /// Convert to `Matrix<C>`.
+    ///
+    /// # Safety
+    ///
+    /// As with [`MaybeUninit::assume_init()`], it is up to the caller to guarantee
+    /// that the value really is in an initialized state. Calling this when the content
+    /// is not yet fully initialized causes immediate undefined behavior.
+    pub unsafe fn assume_init(self) -> Matrix<C> {
+        Matrix {
+            rows: self.rows,
+            columns: self.columns,
+            data: std::mem::transmute(self.data),
+        }
+    }
+}
+
 impl<C> Index<(usize, usize)> for Matrix<C> {
     type Output = C;
 
@@ -726,6 +759,8 @@ impl<'a, C> Iterator for RowIterator<'a, C> {
     }
 }
 
+impl<'a, C> FusedIterator for RowIterator<'a, C> {}
+
 impl<'a, C> IntoIterator for &'a Matrix<C> {
     type IntoIter = RowIterator<'a, C>;
     type Item = &'a [C];
